@@ -612,7 +612,7 @@
     </message>
     <message>
         <location filename="../../ui/settings.ui" line="524"/>
-        <source>Caching graphics</source>
+        <source>Cache graphics to raster</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
