@@ -2,6 +2,29 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="ru">
 <defaultcodec>windows-1251</defaultcodec>
+<context>
+    <name>harmattan</name>
+    <message>
+        <location line="+1"/>
+        <source>Yes</source>
+        <translation>Да</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>No</source>
+        <translation>Нет</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Cancel</source>
+        <translation>Отмена</translation>
+    </message>
+</context>
 <context>
     <name>QSoftKeyManager</name>
     <message>
@@ -344,7 +367,12 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location line="-737"/>
+        <location filename="../../src/mainwindow.cpp" line="+380"/>
+        <source>Installed maps:</source>
+        <translation>Установленные карты:</translation>
+    </message>
+    <message>
+        <location line="-1117"/>
         <source>Loading...</source>
         <translation>Загрузка...</translation>
     </message>
