@@ -33,7 +33,7 @@
 
 
 #ifdef Q_OS_SYMBIAN
-QString VERSION="0.5.7";
+QString VERSION="0.5.8";
 #endif
 
 QString URL_MAPS="http://pmetro.su/Maps.html";
@@ -101,7 +101,7 @@ MainWindow::MainWindow(QWidget *parent) :
  }
 #endif
 #if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
- #if defined(Q_WS_MAEMO_5)
+ #if defined(Q_WS_MAEMO_5) && !defined(QML_EDITION)
  setAttribute(Qt::WA_Maemo5AutoOrientation);
  setAttribute(Qt::WA_Maemo5StackedWindow);
  setAttribute(Qt::WA_Maemo5NonComposited);
@@ -156,7 +156,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
  Config.mapKineticScrollCheck=0; // its work so bad...
  Config.locale=ini->value("Locale","").toString();
- Config.dockWidth=ini->value("DockWidth",0).toInt();
+ Config.dockWidth=ini->value("DockWidth",180).toInt();
  Config.appUiScale=ini->value(IniKeyStr[ikWUiScale],Config.appUiScale).toReal();
 
  key="Mobile";
@@ -165,17 +165,17 @@ MainWindow::MainWindow(QWidget *parent) :
  if(MobileVersion && !ini->contains(key)) ini->setValue(key,1);
  Config.appFullscreen=ini->value(key,0).toBool();
  key="MapZoomFactor";
- Config.mapZoomFactor=ini->value(key).toReal();
+ Config.mapZoomFactor=ini->value(key,1).toReal();
  Config.mapZoomFactorCheck=ini->contains(key);
  key="MapPosition";
- Config.mapPosition=ini->value(key).toPoint();
+ Config.mapPosition=ini->value(key,QPoint()).toPoint();
  Config.mapPositionCheck=ini->contains(key);
 
  Config.appFont.fromString(ini->value("Font",qApp->font().toString()).toString());
  Config.appFirstStart=!ini->contains(IniKeyStr[ikMLastFile]);
  TOOLBAR_STYLE=ini->value("Styles",TOOLBAR_STYLE).toString();
  if(Config.locale.isEmpty()) Config.locale=QLocale::system().name().section("_",0,0);
- if(Config.locale=="uk") Config.locale="ru";
+ if(Config.locale=="uk" || Config.locale=="be" || Config.locale=="kk" || Config.locale=="ab" || Config.locale=="ky") Config.locale="ru";
  toggleLang(Config.locale);
 
  ui->setupUi(this); // UI #############################
@@ -308,19 +308,13 @@ if(LITE)
 
  loadSettings();
 
- if(Config.mapZoomFactorCheck) // first
+ if(Config.mapZoomFactorCheck) // load map scale
  {
   map->scaleMap(Config.mapZoomFactor);
   map->centerOn(map->scene->itemsBoundingRect().center());
  }else
   map->fitMap();
 
- if(Config.mapPositionCheck) // second
- {
-  map->horizontalScrollBar()->setValue(Config.mapPosition.x());
-  map->verticalScrollBar()->setValue(Config.mapPosition.y());
- }
-
  connect(ui->cbDelay,SIGNAL(currentIndexChanged(int)),map,SLOT(setDelayIndex(int)));
  connect(ui->sbDelay,SIGNAL(valueChanged(int)),map,SLOT(setDelayMetro(int)));
 
@@ -379,12 +373,13 @@ if(LITE)
  {
   ui->mSaveScale->setChecked(1);
   ui->mSavePosition->setChecked(1);
+#if !defined(QML_EDITION)
   if(QMessageBox::question(this,windowTitle(),
-                        tr("This is the first launch of the program.\n"
-                           "Want to download more cities?"),QMessageBox::Yes|QMessageBox::No)==QMessageBox::Yes)
+                           getMessageInstalledMaps(),QMessageBox::Yes|QMessageBox::No)==QMessageBox::Yes)
   {
    on_mAddMap_triggered();
   }
+#endif
  }
 
 #ifdef Q_OS_SYMBIAN
@@ -394,6 +389,19 @@ if(LITE)
 #endif
 
  ini->endGroup();
+
+ if(Config.mapPositionCheck) // load map position
+ {
+  int xOffset, yOffset;
+  xOffset=yOffset=0;
+#if defined(MEEGO_EDITION_HARMATTAN)
+  xOffset=-75;
+  yOffset=175;
+#endif
+  map->horizontalScrollBar()->setValue(Config.mapPosition.x()+xOffset);
+  map->verticalScrollBar()->setValue(Config.mapPosition.y()+yOffset);
+ }
+
 }
 
 MainWindow::~MainWindow()
@@ -525,15 +533,22 @@ void MainWindow::on_mExit_triggered()
  close();
 }
 
-void MainWindow::on_mOpen_triggered()
+QString MainWindow::getMapDefaultDir()
+{
+ if(map->params.mapFile.isEmpty())
+       return QString("%1map/").arg(appPath);
+ else  return map->params.mapFile.left(map->params.mapFile.lastIndexOf("/")+1);
+}
+
+void MainWindow::openMap(QString fileName)
 {
  QFileDialog::Options options;
 #ifdef Q_OS_WINCE
  options=QFileDialog::DontUseNativeDialog;
 #endif
- QString MapPath=QString("%1map/").arg(appPath);
+ QString MapPath=getMapDefaultDir();
 
-// ZIPed maps will be unpacked
+// ZIPed maps will be unpacked and updated
  QDir Dir(MapPath);
  if (Dir.exists())
   foreach(QFileInfo info, Dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Files))
@@ -541,15 +556,18 @@ void MainWindow::on_mOpen_triggered()
    QRegExp regExp=QRegExp("*.zip",Qt::CaseInsensitive,QRegExp::Wildcard);
    if(info.isFile() && info.fileName().contains(regExp))
    {
+    QFile::remove(info.absolutePath()+"/"+info.baseName()+".pmz");
+    removeDir(cachePath+info.baseName());
     map->extractFiles(info.absoluteFilePath(),"*.pmz",MapPath);
     QFile::remove(info.absoluteFilePath());
    }
   }
 
- QString fileName = QFileDialog::getOpenFileName(0,
+if(fileName.isEmpty())
+ fileName = QFileDialog::getOpenFileName(0,
             tr("Open file"),MapPath,QString("%1 pMetro (*.pmz)").arg(tr("Map")),0,options);
 
- if (fileName.isEmpty()) return;
+if (fileName.isEmpty()) return;
 
  showPageLoading();
  qApp->processEvents();
@@ -577,6 +595,11 @@ void MainWindow::on_mOpen_triggered()
  showPageMap();
 }
 
+void MainWindow::on_mOpen_triggered()
+{
+ openMap();
+}
+
 void MainWindow::on_mSave_triggered()
 {
  map->saveToFile();
@@ -665,15 +688,15 @@ void MainWindow::on_mPreference_triggered()
 
  if(MobileVersion)
  {
-#ifndef Q_WS_MAEMO_5
+//#ifndef Q_WS_MAEMO_5
   connect(SettingsWindow,SIGNAL(showed()),this,SLOT(toFullScreen()));
   connect(SettingsWindow,SIGNAL(closed()),this,SLOT(showPageMap()));
   connect(SettingsWindow,SIGNAL(closed()),SettingsWindow,SLOT(close()));
   ui->stackMain->addWidget(SettingsWindow);
   ui->stackMain->setCurrentIndex(ui->stackMain->count()-1);
-#else
-  SettingsWindow->show();
-#endif
+//#else
+//  SettingsWindow->show();
+//#endif
 
 
  //      MobileVersion==2 ? SettingWindow->showFullScreen():SettingWindow->showMaximized();
@@ -1116,10 +1139,31 @@ qint64 sizeOfDir(const QString &DirName)
  return Result;
 }
 
+QString MainWindow::getMessageAddMap()
+{
+ QString Text=appPath+"map/";
+ Text=tr("1. Wait until loaded site...\n2. Select map\n3. Save file map here:")+"\n     "+Text;
+ return Text;
+}
+
+QString MainWindow::getMessageInstalledMaps()
+{
+
+ QString MapPath=appPath+"map/";
+ QDir Dir=QDir(MapPath,"*.pmz",QDir::Name,QDir::Files);
+ return tr("This is the first launch of the program.\n"
+           "Want to download more cities?")+"\n\n"
+           +tr("Installed maps:")+"\n"
+           +Dir.entryList().join(", ").remove(".pmz",Qt::CaseInsensitive)+".";
+}
+
+
 void MainWindow::on_mAddMap_triggered()
 {
  QString MapPath=appPath+"map/";
- if(QMessageBox::information(this,tr("Add maps"),tr("1. Wait until loaded site...\n2. Select map\n3. Save file map here:")+"\n     "+MapPath))
+#if !defined(MEEGO_EDITION_HARMATTAN)
+ if(QMessageBox::information(this,tr("Add maps"),getMessageAddMap()))
+#endif
  {
      if(Config.locale!="ru")
          QDesktopServices::openUrl(QUrl(URL_TRANSLATE.arg(Config.locale).arg(URL_MAPS)));
