@@ -87,18 +87,25 @@ public slots:
     void showPageLoading();
     void showPageMap();
 
+    void on_mOpen_triggered();
+    void on_mSave_triggered();
+    void on_mPreference_triggered();
+    void on_mAddMap_triggered();
+    void on_mAbout_triggered();
+
+    QString getMessageAddMap();
+    QString getMessageInstalledMaps();
+    QString getMapDefaultDir();
+    void openMap(QString fileName="");
+
 private slots:
 
     void on_mFullScreen_toggled(bool checked);
-    void on_mAddMap_triggered();
-    void on_mPreference_triggered();
+
     void on_bClear_clicked();
-    void on_mAbout_triggered();
     void on_mFind_toggled(bool checked);
     void on_eSearch_returnPressed();
     void on_mTest_triggered();
-    void on_mSave_triggered();
-    void on_mOpen_triggered();
     void on_mExit_triggered();
     void setDelayNames(QStringList list);
     void nodeInformation();
