@@ -1935,15 +1935,16 @@ void TMapView::defaultConfig()
 {
  QLocale::Country country=QLocale::system().country();
  QString city,mapDir="map/";
- city="Moscow";
 
+ city="Moscow";
  if(country==QLocale::Ukraine) city="Kiev"; else
- if(country==QLocale::Canada) city="Montreal"; else
- if(country==QLocale::UnitedStates) city="New-York"; else
- if(country==QLocale::Czech) city="Praha"; else
- if(country==QLocale::Spanish) city="Madrid"; else
  if(country==QLocale::Mexico) city="Mexico"; else
  if(country==QLocale::France) city="Paris"; else
+ if(country==QLocale::Netherlands) city="Amsterdam"; else
+ if(country==QLocale::Czech) city="Praha"; else
+ if(country==QLocale::Spanish) city="Madrid"; else
+ if(country==QLocale::Canada) city="Montreal"; else
+ if(country==QLocale::UnitedStates) city="New-York"; else
  if(country==QLocale::Belgium) city="Brussels"; else
  if(country==QLocale::Germany) city="Berlin"; else
  if(country==QLocale::Austria) city="Wienn"; else
@@ -1959,14 +1960,14 @@ void TMapView::defaultConfig()
  if(country==QLocale::RepublicOfKorea) city="Seoul"; else
  if(country==QLocale::Japan) city="Tokyo";
 
- city=config.mapLastFile=params.appPath+mapDir+city+".pmz";
- //qDebug() << config.locale << QLocale::system().name() << config.mapLastFile;
+ config.mapLastFile=params.appPath+mapDir+city+".pmz";
 
  if(!QFile::exists(config.mapLastFile))
  {
   QDir Dir=QDir(params.appPath+mapDir,"*.pmz",QDir::Name,QDir::Files);
-  city=Dir.entryList().first();
+  config.mapLastFile=params.appPath+mapDir+Dir.entryList().first();
  }
+ //qDebug() << config.mapLastFile;
  config.enableCustomFont=0;
  config.enableLowqDrag=1;
  config.enableShowScrollBar=0;
