@@ -4,6 +4,8 @@
 //#include <QDebug>
 #include <QtGui/QGraphicsView>
 #include <QTimer>
+#include <QGestureEvent>
+#include <QPinchGesture>
 
 #include "mapelement.h"
 
@@ -11,6 +13,7 @@ class TMapLayer;
 class TMapRoute;
 class TMapNode;
 class TMapEdge;
+class FlickCharm;
 //class TMapElement;
 
 
@@ -71,13 +74,17 @@ private:
 public:
     TMapView(QString AppPath, QString CachePath);
     ~TMapView();
-    void scaleMap(qreal scaleFactor);
+    bool viewportEvent(QEvent *event);
+    bool gestureEvent(QGestureEvent *event);
+    void pinchTriggered(QPinchGesture *gesture);
 
+    void scaleMap(qreal scaleFactor);
     void defaultConfig();
     void applyConfig();
     void loadMap(QString fileName);
     void loadMapImageToPaintCmd(QString imageFile, QList<TPaintCmd> &paintCmd);
     void loadMapLayers(QString LayerFilesTRP); // !! IN LAYER CLASS
+    void initNodeInfo();
     void loadNodeInfo(TMapNode *node);
 
     void clearMap(); // !! DESTRUCT
@@ -112,6 +119,7 @@ public:
 
     QGraphicsScene *scene;
     QPixmap *CachedMap;
+    //QImage *CachedMap;
 
     struct TParams
     {
@@ -120,6 +128,7 @@ public:
      QString mapCachePath;
      QString mapName;
      QString mapCityName;
+     QString mapCityDisplay;
      QString mapCountryName;
      QString mapRusName;
      QString mapNeedVersion;
@@ -135,6 +144,7 @@ public:
      QFont  nodeFont;    // +UpperCase
      QFont  nodeFontDefault;
      int    nodeFontStyle; // +WordWrap
+     QFont  nodeTimeFont;
      QColor nodeColorBack;
      QColor nodeColorShadow;
      bool   nodeUpperCase;
@@ -175,6 +185,8 @@ public:
      bool enableTranslit;
      bool enableCaching;
 
+     bool enableKineticScroll;
+
      bool MobileVersion;
      QString locale;
 
@@ -200,6 +212,7 @@ public:
 
     QTextCodec *codePage;
     QMenu *nodePopup;
+    FlickCharm *fcharm;
 
 public slots:
  void setDelayMetro(int delay);
@@ -222,7 +235,8 @@ signals:
  void trackText(QString Text);
  void trackFinded(bool Check);
  void delayNames(QStringList);
- void nodeClicked(bool VisibleLayer);
+ void nodeClicked(bool clicked);
+ void nodeHasInfo(bool HasInfo);
 
 protected:
     void keyPressEvent(QKeyEvent *event);
@@ -236,7 +250,7 @@ protected:
 
 
     int mapWidth,mapHeight;
-
+    QRect mapRect;
 };
 
 #endif
