@@ -111,6 +111,9 @@ Settings::Settings(QWidget *parent) :
  }else // mobile
  {
   ui->checkMShowScrollbar->setVisible(0);
+#if defined(MEEGO_EDITION_HARMATTAN)
+  ui->checkWFullScreen->setVisible(0);
+#endif
   setAttribute(Qt::WA_DeleteOnClose);
  }
 
